==> thunderbird-77.0b3.source.tar.xz: thunderbird-77.0/gfx/layers/wr/RenderRootTypes.h <==
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set ts=8 sts=2 et sw=2 tw=80: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef GFX_RENDERROOTTYPES_H
#define GFX_RENDERROOTTYPES_H

#include "mozilla/webrender/WebRenderAPI.h"
#include "mozilla/webrender/WebRenderTypes.h"
#include "mozilla/layers/WebRenderMessages.h"
#include "mozilla/layers/WebRenderScrollData.h"
#include "mozilla/Variant.h"

namespace mozilla {

namespace layers {

struct RenderRootDisplayListData {
  wr::RenderRoot mRenderRoot;
  wr::IdNamespace mIdNamespace;
  LayoutDeviceRect mRect;
  nsTArray<WebRenderParentCommand> mCommands;
  wr::LayoutSize mContentSize;
  Maybe<mozilla::ipc::ByteBuf> mDL;
  wr::BuiltDisplayListDescriptor mDLDesc;
  nsTArray<wr::PipelineId> mRemotePipelineIds;
  nsTArray<OpUpdateResource> mResourceUpdates;
  nsTArray<RefCountedShmem> mSmallShmems;
  nsTArray<mozilla::ipc::Shmem> mLargeShmems;
  Maybe<WebRenderScrollData> mScrollData;
};

struct RenderRootUpdates {
  wr::RenderRoot mRenderRoot;
  nsTArray<WebRenderParentCommand> mCommands;
  nsTArray<OpUpdateResource> mResourceUpdates;
  nsTArray<RefCountedShmem> mSmallShmems;
  nsTArray<mozilla::ipc::Shmem> mLargeShmems;
  ScrollUpdatesMap mScrollUpdates;
  uint32_t mPaintSequenceNumber;
};

struct ResourceUpdates {
  nsTArray<OpUpdateResource> mResourceUpdates;
  nsTArray<RefCountedShmem> mSmallShmems;
  nsTArray<mozilla::ipc::Shmem> mLargeShmems;
};

struct ParentCommands {
  nsTArray<WebRenderParentCommand> mCommands;
};

typedef Variant<RenderRootDisplayListData, RenderRootUpdates, ResourceUpdates,
                ParentCommands, FocusTarget>
    RenderRootDeferredData;

}  // namespace layers

namespace ipc {

template <>
struct IPDLParamTraits<mozilla::layers::RenderRootDisplayListData> {
  typedef mozilla::layers::RenderRootDisplayListData paramType;

  static void Write(IPC::Message* aMsg, IProtocol* aActor, paramType&& aParam);

  static bool Read(const IPC::Message* aMsg, PickleIterator* aIter,
                   IProtocol* aActor, paramType* aResult);
};

template <>
struct IPDLParamTraits<mozilla::layers::RenderRootUpdates> {
  typedef mozilla::layers::RenderRootUpdates paramType;

  static void Write(IPC::Message* aMsg, IProtocol* aActor, paramType&& aParam);

  static bool Read(const IPC::Message* aMsg, PickleIterator* aIter,
                   IProtocol* aActor, paramType* aResult);
};

}  // namespace ipc
}  // namespace mozilla

#endif /* GFX_RENDERROOTTYPES_H */

==> thunderbird-78.6.1.source.tar.xz: thunderbird-78.6.1/gfx/layers/wr/RenderRootTypes.h <==
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set ts=8 sts=2 et sw=2 tw=80: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef GFX_RENDERROOTTYPES_H
#define GFX_RENDERROOTTYPES_H

#include "mozilla/webrender/WebRenderAPI.h"
#include "mozilla/webrender/WebRenderTypes.h"
#include "mozilla/layers/WebRenderMessages.h"
#include "mozilla/layers/WebRenderScrollData.h"
#include "mozilla/Variant.h"

namespace mozilla {

namespace layers {

struct DisplayListData {
  wr::IdNamespace mIdNamespace;
  LayoutDeviceRect mRect;
  nsTArray<WebRenderParentCommand> mCommands;
  wr::LayoutSize mContentSize;
  Maybe<mozilla::ipc::ByteBuf> mDL;
  wr::BuiltDisplayListDescriptor mDLDesc;
  nsTArray<wr::PipelineId> mRemotePipelineIds;
  nsTArray<OpUpdateResource> mResourceUpdates;
  nsTArray<RefCountedShmem> mSmallShmems;
  nsTArray<mozilla::ipc::Shmem> mLargeShmems;
  Maybe<WebRenderScrollData> mScrollData;
};

struct TransactionData {
  nsTArray<WebRenderParentCommand> mCommands;
  nsTArray<OpUpdateResource> mResourceUpdates;
  nsTArray<RefCountedShmem> mSmallShmems;
  nsTArray<mozilla::ipc::Shmem> mLargeShmems;
  ScrollUpdatesMap mScrollUpdates;
  uint32_t mPaintSequenceNumber;
};

typedef Maybe<TransactionData> MaybeTransactionData;

}  // namespace layers

namespace ipc {

template <>
struct IPDLParamTraits<mozilla::layers::DisplayListData> {
  typedef mozilla::layers::DisplayListData paramType;

  static void Write(IPC::Message* aMsg, IProtocol* aActor, paramType&& aParam);

  static bool Read(const IPC::Message* aMsg, PickleIterator* aIter,
                   IProtocol* aActor, paramType* aResult);
};

template <>
struct IPDLParamTraits<mozilla::layers::TransactionData> {
  typedef mozilla::layers::TransactionData paramType;

  static void Write(IPC::Message* aMsg, IProtocol* aActor, paramType&& aParam);

  static bool Read(const IPC::Message* aMsg, PickleIterator* aIter,
                   IProtocol* aActor, paramType* aResult);
};

}  // namespace ipc
}  // namespace mozilla

#endif /* GFX_RENDERROOTTYPES_H */
